@@ -84,7 +84,7 @@ def nal(data, cols, alpha=0.3, mul=1):
     if data_local.shape[0] == 0:
         return -np.inf
     else:
-        return nal_counter(data_local, arities, cols, alpha, mul)
+        return nal_counter(data_local, arities, cols, data.shape[0], 0.3 + data_local.shape[0] / data.shape[0] / 10, mul)
 
 
 def nal_sev(data, cols, cols_rvs):
@@ -94,7 +94,7 @@ def nal_sev(data, cols, cols_rvs):
 
 
 @njit(fastmath=True)
-def nal_counter(data, arities, cols, alpha=0.3, mul=1):
+def nal_counter(data, arities, cols, datasize, alpha=0.3, mul=1):
     strides = np.empty(len(cols), dtype=np.uint32)
     idx = len(cols) - 1
     stride = 1
@@ -126,9 +126,9 @@ def nal_counter(data, arities, cols, alpha=0.3, mul=1):
             nal += N_ijk[i] * np.log(N_ijk[i] / N_ij[i])
     nal /= np.sum(N_ijk)
     if alpha == 1:
-        nal -= 0.5 * np.log(data.shape[0]) / data.shape[0] * (arities[cols[0]] - 1) * strides[0]
+        nal -= 0.5 * np.log(datasize) / datasize * (arities[cols[0]] - 1) * strides[0]
     else:
-        nal -= mul / data.shape[1] * np.power(data.shape[0], -alpha) * (arities[cols[0]] - 1) * strides[0]
+        nal -= mul / data.shape[1] * np.power(datasize, -alpha) * (arities[cols[0]] - 1) * strides[0]
     return nal
 
 
