@@ -64,7 +64,7 @@ def check_cycle(vi, vj, dag):
     return cyc_flag
 
 
-def hc(data, method='standard', score_function='default', alpha=0.3, debug=False):
+def hc(data, method='standard', score_function='default', alpha=0.3, mul=1, debug=False):
     '''
         :param data: the training data used for learn BN
         :param method: the method for dealing with missing values, including:
@@ -303,8 +303,8 @@ def hc(data, method='standard', score_function='default', alpha=0.3, debug=False
             raise Exception('Mixed data is not supported.')
         # initialise dag, cached scores and candidate parents for each variable
         dag = {var: {'par': [], 'nei': []} for var in varnames}
-        cache = {var: {tuple([]): local_score(data, [varnames.index(var)], score_function, alpha=alpha)} for var in
-                 varnames}
+        cache = {var: {tuple([]): local_score(data, [varnames.index(var)], score_function, alpha=alpha, mul=mul)} for
+                 var in varnames}
         candidate = {var: [v for v in varnames if v is not var] for var in varnames}
         time_preprocess = time.time() - start_time
         diff = 1
@@ -324,7 +324,7 @@ def hc(data, method='standard', score_function='default', alpha=0.3, debug=False
                         par_sea = tuple(sorted(dag[vj]['par'] + [vi]))
                         if par_sea not in cache[vj]:
                             cols = [varnames.index(x) for x in (vj,) + par_sea]
-                            cache[vj][par_sea] = local_score(data, cols, score_function, alpha=alpha)
+                            cache[vj][par_sea] = local_score(data, cols, score_function, alpha=alpha, mul=mul)
                         time_score += time.time() - start_time
                         diff_temp = cache[vj][par_sea] - cache[vj][tuple(dag[vj]['par'])]
                         if debug:
@@ -344,11 +344,12 @@ def hc(data, method='standard', score_function='default', alpha=0.3, debug=False
                         par_sea_par_vi = tuple(sorted(dag[par_vi]['par'] + [vi]))
                         if par_sea_par_vi not in cache[par_vi]:
                             cols = [varnames.index(x) for x in (par_vi,) + par_sea_par_vi]
-                            cache[par_vi][par_sea_par_vi] = local_score(data, cols, score_function, alpha=alpha)
+                            cache[par_vi][par_sea_par_vi] = local_score(data, cols, score_function, alpha=alpha,
+                                                                        mul=mul)
                         par_sea_vi = tuple([x for x in dag[vi]['par'] if x != par_vi])
                         if par_sea_vi not in cache[vi]:
                             cols = [varnames.index(x) for x in (vi,) + par_sea_vi]
-                            cache[vi][par_sea_vi] = local_score(data, cols, score_function, alpha=alpha)
+                            cache[vi][par_sea_vi] = local_score(data, cols, score_function, alpha=alpha, mul=mul)
                         time_score += time.time() - start_time
                         diff_temp = cache[par_vi][par_sea_par_vi] + cache[vi][par_sea_vi] - cache[par_vi][
                             tuple(dag[par_vi]['par'])] - cache[vi][tuple(dag[vi]['par'])]
@@ -364,7 +365,7 @@ def hc(data, method='standard', score_function='default', alpha=0.3, debug=False
                     par_sea = tuple([x for x in dag[vi]['par'] if x != par_vi])
                     if par_sea not in cache[vi]:
                         cols = [varnames.index(x) for x in (vi,) + par_sea]
-                        cache[vi][par_sea] = local_score(data, cols, score_function, alpha=alpha)
+                        cache[vi][par_sea] = local_score(data, cols, score_function, alpha=alpha, mul=mul)
                     time_score += time.time() - start_time
                     diff_temp = cache[vi][par_sea] - cache[vi][tuple(dag[vi]['par'])]
                     if diff_temp - diff > 1e-10:
@@ -383,7 +384,7 @@ def hc(data, method='standard', score_function='default', alpha=0.3, debug=False
                     (time_total - time_preprocess - time_checkcycle - time_score) / time_total * 100))
     else:
         raise Exception('The input method:' + method + 'is invalid.')
-    return  post_process(dag, dc)
+    return post_process(dag, dc)
 
 
 def pc_stable(data, test='default', threshold=0.05, debug=False):
@@ -815,4 +816,4 @@ def dag_update(dag, edge_candidate, candidate, diff, debug):
             candidate[edge_candidate[1]].append(edge_candidate[0])
         if debug:
             print('best operation is:', edge_candidate, diff)
-    return dag, candidate
\ No newline at end of file
+    return dag, candidate
